#
# spec file for package strip-nondeterminism
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           strip-nondeterminism
Version:        1.13.1
Release:        1.2
Summary:        A tool for stripping non-deterministic information
License:        GPL-3.0-or-later
Group:          Development/Libraries/Perl
URL:            https://anonscm.debian.org/git/reproducible/strip-nondeterminism.git
#Bug-Database: https://salsa.debian.org/reproducible-builds/strip-nondeterminism/-/issues
Source:         https://reproducible-builds.org/_lfs/releases/strip-nondeterminism/strip-nondeterminism-%{version}.tar.bz2
Source1:        https://reproducible-builds.org/_lfs/releases/strip-nondeterminism/strip-nondeterminism-%{version}.tar.bz2.asc
Source2:        rpmmacros
Source3:        strip-all-nondeterminism
Source4:        %{name}.keyring
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl-base
BuildRequires:  perl-macros
BuildRequires:  perl(Archive::Cpio)
BuildRequires:  perl(Archive::Zip)
BuildRequires:  perl(Sub::Override)
Requires:       perl-base
Requires:       perl(Archive::Zip)
Requires:       perl(Sub::Override)
Recommends:     perl(Archive::Cpio)
%{perl_requires}

%description
File::StripNondeterminism is a Perl module for stripping bits of
non-deterministic information, such as timestamps and file system
order, from files such as gzipped files, ZIP archives, and Jar files.
It can be used as a post-processing step to make a build reproducible,
when the build process itself cannot be made deterministic.  It is used
as part of the Reproducible Builds project.

strip-nondeterminism contains the File::StripNondeterminism Perl module,
and the strip-nondeterminism command line utility.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
mkdir -p %buildroot%{_rpmmacrodir} %buildroot/%{_bindir}/
install -p %{SOURCE2} -m 644 %buildroot%{_rpmmacrodir}/macros.strip-nondeterminism
install -p %{SOURCE3} -m 755 %buildroot/%{_bindir}/
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc README TODO
%license COPYING
%{_rpmmacrodir}/macros.strip-nondeterminism

%changelog
* Fri Jul 28 2023 Dirk Stoecker <opensuse@dstoecker.de>
- Update to version 1.13.1
  * Update pyzip regex for latest file(1).
  * Set upstream metadata fields: Bug-Database, Bug-Submit.
  * dh_strip_nondeterminism: use get_non_binnmu_date_epoch() when available.
  * Add a lintian overrides for some false positive tags.
  * Do not fail on JAR archives containing invalid members with a .jar
    extension.
- Drop upstream f1017c67.patch
* Wed Jan 11 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add f1017c67.patch: Support the magic format as returned by file
  5.44 (plus commit dc71304b).
* Mon Jun 14 2021 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to version 1.12.0
  * Also normalise PO-Revision-Date in addition to POT-Creation-Date.
  * Ignore unwritable files, printing a warning.
  * Add a warning message under --verbose statement when the Archive::Cpio
    package is missing. (MR: reproducible-builds/strip-nondeterminism!6)
  * Fix an off-by-one error when parsing PNG modification times.
* Fri Jun 11 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Move macros.strip-nondeterminism from /etc/rpm to
  %%{_rpmmacrodir} (boo#1185657).
- Install the macro file non-executable: it is loaded by rpm, never
  run.
* Tue Oct 29 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.6.1:
  + Parallelise dh_strip_nondeterminism script.
  + Correct indentation level of .zip file field format comment.
  + dh_strip_nondeterminism: Deduplicate hardlinks via stat(2) to
    avoid issues.
  + Call file(1) with the "--" argument placeholder to fix
    normalisation of files.
  + Check the return status from Archive::Zip when writing file to
    disk.
  + Workaround Archive::Zip's incorrect handling of the
    localExtraField field.
  + Support timestamp clamping of "tIME" chunks in .png files.
  + Drop the t/fixtures/zip/bug_803503.zip test fixtures as they
    are no longer compatible with Archive::Zip >= 1.66.
- Drop strip-nondeterminism-0.029-fix-apk.patch: test suite passes
  without this.
- BuildRequire perl(Sub::Override): new dependency.
- Drop _service file: it only has a download_url defined, which is
  also transparently extracted from the spec file. So this service
  essentially serves no purpose.
* Sat Dec 15 2018 bwiedemann@suse.com
- Update to version 1.0.0
  * Improvements for javadoc, zip, cpio and png handling
  * Speed up startup time
- Drop upstream strip-nondeterminism-0.029-zipfix.patch
* Mon Jul 10 2017 bwiedemann@suse.com
- Add strip-all-nondeterminism script to make this easier to use correctly
- Add strip-nondeterminism-0.029-zipfix.patch
  to handle files without permissions in .zip files
* Sun May  7 2017 bwiedemann@suse.com
- add rpm macro to use in spec files
* Sun Jan  1 2017 bwiedemann@suse.com
- update to version 0.029
  + Add strip-nondeterminism-0.029-fix-apk.patch to fix tests
* Tue Mar  8 2016 bwiedemann@suse.com
- initial package version 0.016
